@@ -65,7 +65,7 @@
 
 void elpa_eigenvectors_double(elpa_t handle, double *a, double *ev, double *q, int *error)
 	{
-#if ELPA_WITH_NVIDIA_GPU_VERSION==1 || ELPA_WITH_AMD_GPU_VERSION==1
+#if ELPA_WITH_NVIDIA_GPU_VERSION==1 || ELPA_WITH_AMD_GPU_VERSION==1 || ELPA_WITH_SYCL_GPU_VERSION==1
    void *a_void_ptr = (void*) a;
    int IsDevicePtr = is_device_ptr(a_void_ptr);
 	
@@ -78,7 +78,7 @@ void elpa_eigenvectors_double(elpa_t handle, double *a, double *ev, double *q, i
 		elpa_eigenvectors_a_h_a_d(handle, a, ev, q, error);
 		}	
 #else
-   //printf("elpa_eigenvectors_double non-nvidia version\n");
+	//printf("elpa_eigenvectors_double non-gpu version\n");
 	elpa_eigenvectors_a_h_a_d(handle, a, ev, q, error);
 #endif		
 	}
@@ -178,6 +178,8 @@ void elpa_eigenvectors_float_complex(elpa_t handle, float complex *a, float *ev,
 #endif		
 	}
 
+
+#ifdef HAVE_SKEWSYMMETRIC
 /*! \brief generic C method for elpa_skew_eigenvectors_double
  *
  *  \details
@@ -233,6 +235,7 @@ void elpa_skew_eigenvectors_float(elpa_t handle, float *a, float *ev, float *q,
    elpa_skew_eigenvectors_a_h_a_f(handle, a, ev, q, error);
 #endif		
 	}
+#endif /* HAVE_SKEWSYMMETRIC */
 
 /*! \brief generic C method for elpa_eigenvalues_double
  *
@@ -342,6 +345,7 @@ void elpa_eigenvalues_float_complex(elpa_t handle, float complex *a, float *ev,
 #endif		
 	}
 
+#ifdef HAVE_SKEWSYMMETRIC
 /*! \brief generic C method for elpa_skew_eigenvalues_double
  *
  *  \details
@@ -395,6 +399,7 @@ void elpa_skew_eigenvalues_float(elpa_t handle, float *a, float *ev, int *error)
    elpa_skew_eigenvalues_a_h_a_f(handle, a, ev, error);
 #endif		
 	}
+#endif /* HAVE_SKEWSYMMETRIC */
 
 /*! \brief generic C method for elpa_cholesky_double
  *
@@ -743,4 +748,4 @@ void elpa_invert_triangular_float_complex(elpa_t handle, float complex *a, int *
 #else
    elpa_invert_trm_a_h_a_fc(handle, a, error);
 #endif		
-	}
\ No newline at end of file
+	}
