@@ -49,11 +49,11 @@
 #define REALCASE 1
 #define SINGLE_PRECISION 1
 #define BLOCK6 1
-#define VEC_SET SVE_128
+#define VEC_SET SVE_512
 #include "../../general/precision_macros.h"
 #include "real_128bit_256bit_512bit_BLOCK_template.c"
-#undef REALCASE
-#undef VEC_SET
 #undef BLOCK6
-#undef SINGLE__PRECISION
+#undef VEC_SET
+#undef REALCASE
+#undef SINGLE_PRECISION
 
