@@ -64,7 +64,7 @@ int set_max_threads_glob_1=0;
 #ifdef WITH_AMD_GPU_VERSION
 #define default_max_stored_rows 256
 #else
-int const default_max_stored_rows = 256;   
+int const default_max_stored_rows = 256;
 #endif
 
 static int enumerate_identity(elpa_index_t index, int i);
@@ -95,6 +95,14 @@ static int band_to_full_cardinality(elpa_index_t index);
 static int band_to_full_enumerate(elpa_index_t index, int i);
 static int band_to_full_is_valid(elpa_index_t index, int n, int new_value);
 
+static int hermitian_multiply_cardinality(elpa_index_t index);
+static int hermitian_multiply_enumerate(elpa_index_t index, int i);
+static int hermitian_multiply_is_valid(elpa_index_t index, int n, int new_value);
+
+static int cholesky_cardinality(elpa_index_t index);
+static int cholesky_enumerate(elpa_index_t index, int i);
+static int cholesky_is_valid(elpa_index_t index, int n, int new_value);
+
 static int stripewidth_real_cardinality(elpa_index_t index);
 static int stripewidth_real_enumerate(elpa_index_t index, int i);
 static int stripewidth_real_is_valid(elpa_index_t index, int n, int new_value);
@@ -126,7 +134,7 @@ int nvidia_gpu_count();
 int amd_gpu_count();
 #endif
 #ifdef WITH_SYCL_GPU_VERSION
-int sycl_gpu_count();
+int sycl_gpu_count(int);
 #endif
 #ifdef WITH_OPENMP_OFFLOAD_GPU_VERSION
 int openmp_offload_gpu_count();
@@ -155,6 +163,7 @@ static int output_build_config_is_valid(elpa_index_t index, int n, int new_value
 static int nvidia_gpu_is_valid(elpa_index_t index, int n, int new_value);
 static int amd_gpu_is_valid(elpa_index_t index, int n, int new_value);
 static int intel_gpu_is_valid(elpa_index_t index, int n, int new_value);
+static int expose_all_sycl_devices_is_valid(elpa_index_t index, int n, int new_value);
 static int nbc_is_valid(elpa_index_t index, int n, int new_value);
 static int nbc_elpa1_is_valid(elpa_index_t index, int n, int new_value);
 static int nbc_elpa2_is_valid(elpa_index_t index, int n, int new_value);
@@ -168,7 +177,7 @@ static int elpa_float_value_to_string(char *name, float value, const char **stri
 static int elpa_double_string_to_value(char *name, char *string, double *value);
 static int elpa_double_value_to_string(char *name, double value, const char **string);
 
-         
+
 #define BASE_ENTRY(option_name, option_description, once_value, readonly_value, print_flag_value) \
                 .base = { \
                         .name = option_name, \
@@ -256,7 +265,8 @@ static const elpa_index_int_entry_t int_entries[] = {
         BOOL_ENTRY("measure_performance", "Also measure with flops (via papi) with the timings", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, 0, ELPA_AUTOTUNE_PART_NONE, PRINT_YES),
         BOOL_ENTRY("check_pd", "Check eigenvalues to be positive", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, 0, ELPA_AUTOTUNE_PART_NONE, PRINT_YES),
         BOOL_ENTRY("output_pinning_information", "Print the pinning information", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, 0, ELPA_AUTOTUNE_PART_NONE, PRINT_YES),
-        BOOL_ENTRY("cannon_for_generalized", "Whether to use Cannons algorithm for the generalized EVP", 1, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, 0, ELPA_AUTOTUNE_PART_NONE, PRINT_YES),
+        BOOL_ENTRY("cannon_for_generalized", "Whether to use Cannons algorithm for the generalized EVP" , 1, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, 0, ELPA_AUTOTUNE_PART_NONE, PRINT_YES),
+        BOOL_ENTRY("pxtrmm_for_generalized", "Whether to use ScaLAPACK's PxTRMM for the generalized EVP", 1, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, 0, ELPA_AUTOTUNE_PART_NONE, PRINT_YES),
 #if defined(THREADING_SUPPORT_CHECK) && defined(ALLOW_THREAD_LIMITING) && !defined(HAVE_SUFFICIENT_MPI_THREADING_SUPPORT)
         BOOL_ENTRY("limit_openmp_threads", "Limit the number if openmp threads to 1", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, 0, ELPA_AUTOTUNE_PART_NONE, PRINT_NO),
 #endif
@@ -314,22 +324,45 @@ static const elpa_index_int_entry_t int_entries[] = {
         INT_ENTRY("nbc_all_elpa2_main", "Use non blocking collectives for comm_world in elpa2_main", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA2_AUTOTUNE_MAIN, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ELPA2, \
                         cardinality_bool, enumerate_identity, nbc_elpa2_is_valid, NULL, PRINT_YES),
 	// 2. GPU usage
+#if defined(WITH_NVIDIA_GPU_VERSION)
+        INT_ENTRY("gpu", "Use Nvidia GPU acceleration", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
+                         cardinality_bool, enumerate_identity, nvidia_gpu_is_valid, NULL, PRINT_YES),
+        INT_ENTRY("nvidia-gpu", "Use Nvidia GPU acceleration", 0, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
+                         cardinality_bool, enumerate_identity, nvidia_gpu_is_valid, NULL, PRINT_YES),
+#else
         INT_ENTRY("gpu", "Use Nvidia GPU acceleration", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
                         cardinality_bool, enumerate_identity, nvidia_gpu_is_valid, NULL, PRINT_YES),
-        INT_ENTRY("nvidia-gpu", "Use Nvidia GPU acceleration", 0, ELPA_AUTOTUNE_FAST, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
+        INT_ENTRY("nvidia-gpu", "Use Nvidia GPU acceleration", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
                         cardinality_bool, enumerate_identity, nvidia_gpu_is_valid, NULL, PRINT_YES),
+#endif
+#if defined(WITH_OPENMP_OFFLOAD_GPU_VERSION) || defined(WITH_SYCL_GPU_VERSION)
+        INT_ENTRY("intel-gpu", "Use INTEL GPU acceleration", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
+                         cardinality_bool, enumerate_identity, intel_gpu_is_valid, NULL, PRINT_YES),
+#else
         INT_ENTRY("intel-gpu", "Use INTEL GPU acceleration", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
                         cardinality_bool, enumerate_identity, intel_gpu_is_valid, NULL, PRINT_YES),
-        INT_ENTRY("amd-gpu", "Use AMD GPU acceleration", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
+#endif
+#if defined(WITH_AMD_GPU_VERSION)
+        INT_ENTRY("amd-gpu", "Use AMD GPU acceleration", 0, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
                         cardinality_bool, enumerate_identity, amd_gpu_is_valid, NULL, PRINT_YES),
-        //default of gpu ussage for individual phases is 1. However, it is only evaluated, if GPU is used at all, which first has to be determined
+#else
+        INT_ENTRY("amd-gpu", "Use AMD GPU acceleration", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
+                         cardinality_bool, enumerate_identity, amd_gpu_is_valid, NULL, PRINT_YES),
+#endif
+
+        // For SYCL, currently ELPA ignores non-GPU devices.
+        INT_ENTRY("sycl_show_all_devices", "Utilize ALL SYCL devices, not just level zero GPUs.", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
+                        cardinality_bool, enumerate_identity, expose_all_sycl_devices_is_valid, NULL, PRINT_YES),
+        //default of gpu usage for individual phases is 1. However, it is only evaluated, if GPU is used at all, which first has to be determined
         //by the parameter gpu and presence of the device
+        INT_ENTRY("gpu_cannon", "Use GPU acceleration for Cannon's algorithm", 1, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
+                        cardinality_bool, enumerate_identity, valid_with_gpu, NULL, PRINT_YES),
+        INT_ENTRY("gpu_cholesky", "Use GPU acceleration for elpa_cholesky", 1, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
+                        cardinality_bool, enumerate_identity, valid_with_gpu, NULL, PRINT_YES),
         INT_ENTRY("gpu_hermitian_multiply", "Use GPU acceleration for elpa_hermitian_multiply", 1, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
                         cardinality_bool, enumerate_identity, valid_with_gpu, NULL, PRINT_YES),
         INT_ENTRY("gpu_invert_trm", "Use GPU acceleration for elpa_triangular", 1, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
                         cardinality_bool, enumerate_identity, valid_with_gpu, NULL, PRINT_YES),
-        INT_ENTRY("gpu_cholesky", "Use GPU acceleration for elpa_cholesky", 1, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
-                        cardinality_bool, enumerate_identity, valid_with_gpu, NULL, PRINT_YES),
         INT_ENTRY("gpu_tridiag", "Use GPU acceleration for ELPA1 tridiagonalization", 1, ELPA_AUTOTUNE_MEDIUM, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ELPA1, \
                         cardinality_bool, enumerate_identity, valid_with_gpu_elpa1, NULL, PRINT_YES),
         INT_ENTRY("gpu_solve_tridi", "Use GPU acceleration for ELPA solve tridi", 1, ELPA_AUTOTUNE_MEDIUM, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
@@ -378,13 +411,17 @@ static const elpa_index_int_entry_t int_entries[] = {
 	// 2. max_stored_rows
         INT_ENTRY("max_stored_rows", "Maximum number of stored rows used in ELPA 1 backtransformation", default_max_stored_rows, ELPA_AUTOTUNE_EXTENSIVE, ELPA1_AUTOTUNE_MAX_STORED_ROWS, ELPA_AUTOTUNE_DOMAIN_ANY,  ELPA_AUTOTUNE_PART_ELPA1, \
                         max_stored_rows_cardinality, max_stored_rows_enumerate, max_stored_rows_is_valid, NULL, PRINT_YES),
-	// 3. stripewidth
+	// 4. BLOCKING in hermitian_multiply
+        INT_ENTRY("blocking_in_multiply", "Blocking used in hermitian multiply, default", 31, ELPA_AUTOTUNE_EXTENSIVE, ELPA2_AUTOTUNE_HERMITIAN_MULTIPLY_BLOCKING, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ELPA2, \
+                        hermitian_multiply_cardinality, hermitian_multiply_enumerate, hermitian_multiply_is_valid, NULL, PRINT_YES),
+	// 5. BLOCKING in cholesky
+        INT_ENTRY("blocking_in_cholesky", "Blocking used in cholesky, default", 128, ELPA_AUTOTUNE_EXTENSIVE, ELPA2_AUTOTUNE_CHOLESKY_BLOCKING, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ELPA2, \
+                        cholesky_cardinality, cholesky_enumerate, cholesky_is_valid, NULL, PRINT_YES),
+	//6. stripewidth
         INT_ENTRY("stripewidth_real", "Stripewidth_real, default 48. Must be a multiple of 4", 48, ELPA_AUTOTUNE_EXTENSIVE, ELPA2_AUTOTUNE_TRIDI_TO_BAND_STRIPEWIDTH, ELPA_AUTOTUNE_DOMAIN_REAL,  ELPA_AUTOTUNE_PART_ELPA2, \
                         stripewidth_real_cardinality, stripewidth_real_enumerate, stripewidth_real_is_valid, NULL, PRINT_YES),
         INT_ENTRY("stripewidth_complex", "Stripewidth_complex, default 96. Must be a multiple of 8", 96, ELPA_AUTOTUNE_EXTENSIVE, ELPA2_AUTOTUNE_TRIDI_TO_BAND_STRIPEWIDTH, ELPA_AUTOTUNE_DOMAIN_COMPLEX, ELPA_AUTOTUNE_PART_ELPA2, \
                         stripewidth_complex_cardinality, stripewidth_complex_enumerate, stripewidth_complex_is_valid, NULL, PRINT_YES),
-        INT_ENTRY("min_tile_size", "Minimal tile size used internally in elpa1_tridiag and elpa2_bandred", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
-                        min_tile_size_cardinality, min_tile_size_enumerate, min_tile_size_is_valid, NULL, PRINT_YES),
 };
 
 #define READONLY_FLOAT_ENTRY(option_name, option_description) \
@@ -1042,6 +1079,14 @@ static int intel_gpu_is_valid(elpa_index_t index, int n, int new_value) {
 #endif
 }
 
+static int expose_all_sycl_devices_is_valid(elpa_index_t index, int n, int new_value) {
+#if defined(WITH_OPENMP_OFFLOAD_GPU_VERSION) || defined(WITH_SYCL_GPU_VERSION)
+        return new_value == 0 || new_value == 1;
+#else
+        return new_value == 0;
+#endif
+}
+
 static int nbc_is_valid(elpa_index_t index, int n, int new_value) {
         return new_value == 0 || new_value == 1;
 }
@@ -1077,6 +1122,20 @@ static int band_to_full_enumerate(elpa_index_t index, int i) {
 	return i+1;
 }
 
+static int hermitian_multiply_cardinality(elpa_index_t index) {
+	return 4100;
+}
+static int hermitian_multiply_enumerate(elpa_index_t index, int i) {
+	return i+1;
+}
+
+static int cholesky_cardinality(elpa_index_t index) {
+	return 4096;
+}
+static int cholesky_enumerate(elpa_index_t index, int i) {
+	return i+1;
+}
+
 static int internal_nblk_is_valid(elpa_index_t index, int n, int new_value) {
         return (0 <= new_value);
 }
@@ -1113,6 +1172,17 @@ static int band_to_full_is_valid(elpa_index_t index, int n, int new_value) {
         return (1 <= new_value) && (new_value <= max_block);
 }
 
+static int hermitian_multiply_is_valid(elpa_index_t index, int n, int new_value) {
+	int max_block=4100;
+        return (1 <= new_value) && (new_value <= max_block);
+}
+
+static int cholesky_is_valid(elpa_index_t index, int n, int new_value) {
+	int max_block=4096;
+        return (1 <= new_value) && (new_value <= max_block);
+}
+
+
 static int stripewidth_real_cardinality(elpa_index_t index) {
 	return 17;
 }
@@ -1329,7 +1399,8 @@ static int use_gpu_id_cardinality(elpa_index_t index) {
 	return count;
 #elif WITH_SYCL_GPU_VERSION
 	int count;
-	count = sycl_gpu_count();
+        int show_all_sycl_devices = elpa_index_get_int_value(index, "sycl_show_all_devices", NULL);
+	count = sycl_gpu_count(show_all_sycl_devices);
         if (count == -1000) {
           fprintf(stderr, "Querrying GPUs failed! Set GPU count = 0\n");
 	return 0;
@@ -1558,7 +1629,7 @@ int elpa_index_autotune_cardinality_new_stepping(elpa_index_t index, int autotun
                         N_level[level] *= int_entries[i].cardinality(index);
                    }
 	    }
-		   if (N_level[level] == 1) { N_level[level] = 0;} 
+		   if (N_level[level] == 1) { N_level[level] = 0;}
           }
 	for (int i=1;i<autotune_level+1;i++){
 	  N += N_level[i];
@@ -1570,10 +1641,11 @@ void elpa_index_print_int_parameter(elpa_index_t index, char* buff, int i)
 {
         int value = index->int_options.values[i];
         sprintf(buff, "%s = ", int_entries[i].base.name);
+        size_t used_length = strlen(buff);
         if (int_entries[i].to_string) {
-                sprintf(buff, "%s%d -> %s\n", buff, value, int_entries[i].to_string(value));
+                sprintf(buff + used_length, "%d -> %s\n", value, int_entries[i].to_string(value));
         } else {
-                sprintf(buff, "%s%d\n", buff, value);
+                sprintf(buff + used_length, "%d\n", value);
         }
 }
 
@@ -1597,7 +1669,7 @@ int elpa_index_set_autotune_parameters(elpa_index_t index, int autotune_level_ol
                current_cpy /= int_entries[i].cardinality(index);
            }
         }
-	
+
         if (debug == 1 && elpa_index_is_printing_mpi_rank(index)) {
                 fprintf(stderr, "\n*** AUTOTUNING: setting a new combination of parameters, idx %d for level %s ***\n", current, elpa_autotune_level_name(autotune_level_old));
                 elpa_index_print_autotune_parameters(index, autotune_level_old, autotune_domain);
@@ -1629,7 +1701,7 @@ int elpa_index_set_autotune_parameters_new_stepping(elpa_index_t index, int auto
                current_cpy /= int_entries[i].cardinality(index);
            }
         }
-	
+
         if (debug == 1 && elpa_index_is_printing_mpi_rank(index)) {
                 fprintf(stderr, "\n*** AUTOTUNING: setting a new combination of parameters, idx %d for level %s ***\n", current, elpa_autotune_level_name(autotune_level));
                 elpa_index_print_autotune_parameters_new_stepping(index, autotune_level, autotune_domain, autotune_part);
@@ -1893,7 +1965,8 @@ int elpa_index_print_settings(elpa_index_t index, char *file_name) {
                         } else
                                 out = &out_nowhere;
                         elpa_index_print_int_parameter(index, buff, i);
-                        sprintf(*out, "%s%s", *out, buff);
+                        size_t used_length = strlen(*out);
+                        sprintf(*out + used_length, "%s", buff);
                 }
                 int output_to_file = (strlen(file_name) > 0);
                 if(output_to_file) {
