@@ -55,6 +55,7 @@
 #undef  BLAS_TRANS_OR_CONJ
 #undef  BLAS_CHAR
 #undef  BLAS_CHAR_AND_SY_OR_HE
+#undef  PRECISION_CHAR
 #undef  PRECISION
 #undef  SPECIAL_COMPLEX_DATATYPE
 #undef  PRECISION_STR
@@ -102,6 +103,8 @@
 #undef  gpublas_PRECISION_SYMV
 #undef  gpublas_PRECISION_COPY
 #undef  gpublas_PRECISION_TRSM
+#undef  gpublas_PRECISION_DOT
+#undef  gpublas_PRECISION_SCAL
 #undef  gpusolver_PRECISION_TRTRI
 #undef  gpusolver_PRECISION_POTRF
 #undef  cublas_PRECISION_GEMM
@@ -115,6 +118,18 @@
 #undef  gpu_copy_PRECISION_tmp2_tmat2
 #undef  gpu_copy_PRECISION_a_tmat1
 #undef  gpu_copy_PRECISION_a_tmatc
+#undef  gpu_copy_PRECISION_a_aux_bc
+#undef  gpu_copy_PRECISION_aux_bc_aux_mat
+#undef  gpu_copy_PRECISION_tmp2_c
+#undef  gpu_copy_and_set_zeros_PRECISION
+#undef  gpu_dot_product_PRECISION
+#undef  gpu_dot_product_and_assign_PRECISION
+#undef  gpu_set_e_vec_scale_set_one_store_v_row_PRECISION
+#undef  gpu_store_u_v_in_uv_vu_PRECISION
+#undef  gpu_update_matrix_element_add_PRECISION
+#undef  gpu_update_array_element_add_PRECISION
+#undef  gpu_hh_transform_PRECISION
+#undef  gpu_transpose_reduceadd_vectors_copy_block_PRECISION
 #undef  mkl_offload_PRECISION_GEMM
 #undef  mkl_offload_PRECISION_GEMV
 #undef  mkl_offload_PRECISION_TRMM
@@ -134,6 +149,11 @@
 #undef  MPI_MATH_DATATYPE_PRECISION_EXPL
 #undef  C_DATATYPE_KIND
 
+#undef  GPU_ZERO_SKEWSYMMETRIC_Q_PRECISION
+#undef  GPU_COPY_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION
+#undef  GPU_COPY_SKEWSYMMETRIC_FIRST_HALF_Q_PRECISION
+#undef  GPU_GET_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION
+#undef  GPU_PUT_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION
 
 #if 0
 /* General definitions needed in single and double case */
@@ -152,7 +172,8 @@
 #define  REAL_DATATYPE rk8
 #define  C_REAL_DATATYPE c_double
 #define  BLAS_CHAR D
-#define BLAS_CHAR_AND_SY_OR_HE DSY
+#define  BLAS_CHAR_AND_SY_OR_HE DSY
+#define  PRECISION_CHAR 'D'
 #define  SPECIAL_COMPLEX_DATATYPE ck8
 
 #define  PRECISION_TRTRI DTRTRI
@@ -191,6 +212,8 @@
 #define  gpublas_PRECISION_SYMV gpublas_DSYMV
 #define  gpublas_PRECISION_COPY gpublas_DCOPY
 #define  gpublas_PRECISION_TRSM gpublas_DTRSM
+#define  gpublas_PRECISION_DOT  gpublas_DDOT
+#define  gpublas_PRECISION_SCAL gpublas_DSCAL
 #define  gpusolver_PRECISION_TRTRI gpusolver_DTRTRI
 #define  gpusolver_PRECISION_POTRF gpusolver_DPOTRF
 #define  cublas_PRECISION_GEMM cublas_DGEMM
@@ -204,6 +227,18 @@
 #define  gpu_copy_PRECISION_tmp2_tmat2 gpu_copy_double_tmp2_tmat2
 #define  gpu_copy_PRECISION_a_tmat1 gpu_copy_double_a_tmat1
 #define  gpu_copy_PRECISION_a_tmatc gpu_copy_double_a_tmatc
+#define  gpu_copy_PRECISION_a_aux_bc gpu_copy_double_a_aux_bc
+#define  gpu_copy_PRECISION_aux_bc_aux_mat gpu_copy_double_aux_bc_aux_mat
+#define  gpu_copy_PRECISION_tmp2_c gpu_copy_double_tmp2_c
+#define  gpu_copy_and_set_zeros_PRECISION gpu_copy_and_set_zeros_double
+#define  gpu_dot_product_PRECISION gpu_dot_product_double
+#define  gpu_dot_product_and_assign_PRECISION gpu_dot_product_and_assign_double
+#define  gpu_set_e_vec_scale_set_one_store_v_row_PRECISION gpu_set_e_vec_scale_set_one_store_v_row_double
+#define  gpu_store_u_v_in_uv_vu_PRECISION gpu_store_u_v_in_uv_vu_double
+#define  gpu_update_matrix_element_add_PRECISION gpu_update_matrix_element_add_double
+#define  gpu_update_array_element_add_PRECISION gpu_update_array_element_add_double
+#define  gpu_hh_transform_PRECISION gpu_hh_transform_double
+#define  gpu_transpose_reduceadd_vectors_copy_block_PRECISION gpu_transpose_reduceadd_vectors_copy_block_double
 #define  mkl_offload_PRECISION_GEMM mkl_offload_DGEMM
 #define  mkl_offload_PRECISION_GEMV mkl_offload_DGEMV
 #define  mkl_offload_PRECISION_TRMM mkl_offload_DTRMM
@@ -225,6 +260,12 @@
 #define C_PLACPY pdlacpy_
 #define C_PTRAN pdtran_
 
+#define GPU_ZERO_SKEWSYMMETRIC_Q_PRECISION gpu_zero_skewsymmetric_q_double
+#define GPU_COPY_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION gpu_copy_skewsymmetric_second_half_q_double
+#define GPU_COPY_SKEWSYMMETRIC_FIRST_HALF_Q_PRECISION gpu_copy_skewsymmetric_first_half_q_double
+#define GPU_GET_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION gpu_get_skewsymmetric_second_half_q_double
+#define GPU_PUT_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION gpu_put_skewsymmetric_second_half_q_double
+
 #endif /* DOUBLE_PRECISION */
 
 #ifdef SINGLE_PRECISION
@@ -239,6 +280,7 @@
 #define  C_REAL_DATATYPE c_float
 #define  BLAS_CHAR S
 #define  BLAS_CHAR_AND_SY_OR_HE SSY
+#define  PRECISION_CHAR 'S'
 #define  SPECIAL_COMPLEX_DATATYPE ck4
 
 #define  PRECISION_TRTRI STRTRI
@@ -277,6 +319,8 @@
 #define  gpublas_PRECISION_SYMV gpublas_SSYMV
 #define  gpublas_PRECISION_COPY gpublas_SCOPY
 #define  gpublas_PRECISION_TRSM gpublas_STRSM
+#define  gpublas_PRECISION_DOT  gpublas_SDOT
+#define  gpublas_PRECISION_SCAL gpublas_SSCAL
 #define  gpusolver_PRECISION_TRTRI gpusolver_STRTRI
 #define  gpusolver_PRECISION_POTRF gpusolver_SPOTRF
 #define  cublas_PRECISION_GEMM cublas_SGEMM
@@ -290,6 +334,18 @@
 #define  gpu_copy_PRECISION_tmp2_tmat2 gpu_copy_float_tmp2_tmat2
 #define  gpu_copy_PRECISION_a_tmat1 gpu_copy_float_a_tmat1
 #define  gpu_copy_PRECISION_a_tmatc gpu_copy_float_a_tmatc
+#define  gpu_copy_PRECISION_a_aux_bc gpu_copy_float_a_aux_bc
+#define  gpu_copy_PRECISION_aux_bc_aux_mat gpu_copy_float_aux_bc_aux_mat
+#define  gpu_copy_PRECISION_tmp2_c gpu_copy_float_tmp2_c
+#define  gpu_copy_and_set_zeros_PRECISION gpu_copy_and_set_zeros_float
+#define  gpu_dot_product_PRECISION gpu_dot_product_float
+#define  gpu_dot_product_and_assign_PRECISION gpu_dot_product_and_assign_float
+#define  gpu_set_e_vec_scale_set_one_store_v_row_PRECISION gpu_set_e_vec_scale_set_one_store_v_row_float
+#define  gpu_store_u_v_in_uv_vu_PRECISION gpu_store_u_v_in_uv_vu_float
+#define  gpu_update_matrix_element_add_PRECISION gpu_update_matrix_element_add_float
+#define  gpu_update_array_element_add_PRECISION gpu_update_array_element_add_float
+#define  gpu_hh_transform_PRECISION gpu_hh_transform_float
+#define  gpu_transpose_reduceadd_vectors_copy_block_PRECISION gpu_transpose_reduceadd_vectors_copy_block_float
 #define  mkl_offload_PRECISION_GEMM mkl_offload_SGEMM
 #define  mkl_offload_PRECISION_GEMV mkl_offload_SGEMV
 #define  mkl_offload_PRECISION_TRMM mkl_offload_STRMM
@@ -311,6 +367,12 @@
 #define C_PLACPY pslacpy_
 #define C_PTRAN pstran_
 
+#define GPU_ZERO_SKEWSYMMETRIC_Q_PRECISION gpu_zero_skewsymmetric_q_float
+#define GPU_COPY_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION gpu_copy_skewsymmetric_second_half_q_float
+#define GPU_COPY_SKEWSYMMETRIC_FIRST_HALF_Q_PRECISION gpu_copy_skewsymmetric_first_half_q_float
+#define GPU_GET_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION gpu_get_skewsymmetric_second_half_q_float
+#define GPU_PUT_SKEWSYMMETRIC_SECOND_HALF_Q_PRECISION gpu_put_skewsymmetric_second_half_q_float
+
 #endif /* SINGLE_PRECISION */
 
 #endif /* REALCASE */
@@ -323,6 +385,7 @@
 #undef  BLAS_TRANS_OR_CONJ
 #undef  BLAS_CHAR
 #undef  BLAS_CHAR_AND_SY_OR_HE
+#undef  PRECISION_CHAR
 #undef  PRECISION
 #undef COMPLEX_DATATYPE
 
@@ -376,6 +439,9 @@
 #undef  gpublas_PRECISION_SYMV
 #undef  gpublas_PRECISION_COPY
 #undef  gpublas_PRECISION_TRSM
+#undef  gpublas_PRECISION_DCAL
+#undef  gpublas_PRECISION_DOT
+#undef  gpublas_PRECISION_SCAL
 #undef  cublas_PRECISION_GEMM
 #undef  cublas_PRECISION_TRMM
 #undef  cublas_PRECISION_GEMV
@@ -387,6 +453,18 @@
 #undef  gpu_copy_PRECISION_tmp2_tmat2
 #undef  gpu_copy_PRECISION_a_tmat1
 #undef  gpu_copy_PRECISION_a_tmatc
+#undef  gpu_copy_PRECISION_a_aux_bc
+#undef  gpu_copy_PRECISION_aux_bc_aux_mat
+#undef  gpu_copy_PRECISION_tmp2_c
+#undef  gpu_copy_and_set_zeros_PRECISION
+#undef  gpu_dot_product_PRECISION
+#undef  gpu_dot_product_and_assign_PRECISION
+#undef  gpu_set_e_vec_scale_set_one_store_v_row_PRECISION
+#undef  gpu_store_u_v_in_uv_vu_PRECISION
+#undef  gpu_update_matrix_element_add_PRECISION
+#undef  gpu_update_array_element_add_PRECISION
+#undef  gpu_hh_transform_PRECISION
+#undef  gpu_transpose_reduceadd_vectors_copy_block_PRECISION
 #undef  gpusolver_PRECISION_TRTRI
 #undef  gpusolver_PRECISION_POTRF
 #undef  mkl_offload_PRECISION_GEMM 
@@ -413,6 +491,8 @@
 #undef ELPA_PRECISION_SSMV
 #undef ELPA_PRECISION_SSR2
 
+#undef  GPU_SCALE_QMAT_PRECISION
+#undef  GPU_COPY_REAL_PART_TO_Q_PRECISION
 
 #if 0
 /* General definitions needed in single and double case */
@@ -431,6 +511,7 @@
 #define COMPLEX_DATATYPE CK8
 #define BLAS_CHAR Z
 #define BLAS_CHAR_AND_SY_OR_HE ZHE
+#define PRECISION_CHAR 'Z'
 #define REAL_DATATYPE RK8
 #define C_REAL_DATATYPE c_double
 
@@ -475,6 +556,8 @@
 #define  gpublas_PRECISION_SYMV gpublas_ZSYMV
 #define  gpublas_PRECISION_COPY gpublas_ZCOPY
 #define  gpublas_PRECISION_TRSM gpublas_ZTRSM
+#define  gpublas_PRECISION_DOT gpublas_ZDOT
+#define  gpublas_PRECISION_SCAL gpublas_ZSCAL
 #define  gpusolver_PRECISION_TRTRI gpusolver_ZTRTRI
 #define  gpusolver_PRECISION_POTRF gpusolver_ZPOTRF
 #define  cublas_PRECISION_GEMM cublas_ZGEMM
@@ -488,6 +571,18 @@
 #define  gpu_copy_PRECISION_tmp2_tmat2 gpu_copy_double_complex_tmp2_tmat2
 #define  gpu_copy_PRECISION_a_tmat1 gpu_copy_double_complex_a_tmat1
 #define  gpu_copy_PRECISION_a_tmatc gpu_copy_double_complex_a_tmatc
+#define  gpu_copy_PRECISION_a_aux_bc gpu_copy_double_complex_a_aux_bc
+#define  gpu_copy_PRECISION_aux_bc_aux_mat gpu_copy_double_complex_aux_bc_aux_mat
+#define  gpu_copy_PRECISION_tmp2_c gpu_copy_double_complex_tmp2_c
+#define  gpu_copy_and_set_zeros_PRECISION gpu_copy_and_set_zeros_double_complex
+#define  gpu_dot_product_PRECISION gpu_dot_product_double_complex
+#define  gpu_dot_product_and_assign_PRECISION gpu_dot_product_and_assign_double_complex
+#define  gpu_set_e_vec_scale_set_one_store_v_row_PRECISION gpu_set_e_vec_scale_set_one_store_v_row_double_complex
+#define  gpu_store_u_v_in_uv_vu_PRECISION gpu_store_u_v_in_uv_vu_double_complex
+#define  gpu_update_matrix_element_add_PRECISION gpu_update_matrix_element_add_double_complex
+#define  gpu_update_array_element_add_PRECISION gpu_update_array_element_add_double_complex
+#define  gpu_hh_transform_PRECISION gpu_hh_transform_double_complex
+#define  gpu_transpose_reduceadd_vectors_copy_block_PRECISION gpu_transpose_reduceadd_vectors_copy_block_double_complex
 #define  mkl_offload_PRECISION_GEMM mkl_offload_ZGEMM
 #define  mkl_offload_PRECISION_GEMV mkl_offload_ZGEMV
 #define  mkl_offload_PRECISION_TRMM mkl_offload_ZTRMM
@@ -507,6 +602,9 @@
 #define  PRECISION_REAL DREAL
 #define  C_DATATYPE_KIND c_double
 
+#define GPU_SCALE_QMAT_PRECISION gpu_scale_qmat_double_complex
+#define GPU_COPY_REAL_PART_TO_Q_PRECISION gpu_copy_real_part_to_q_double_complex
+
 #define ELPA_PRECISION_SSMV elpa_zssmv
 #define ELPA_PRECISION_SSR2 elpa_zssr2
 
@@ -521,6 +619,7 @@
 #define COMPLEX_DATATYPE CK4
 #define BLAS_CHAR C
 #define BLAS_CHAR_AND_SY_OR_HE CHE
+#define PRECISION_CHAR 'C'
 #define REAL_DATATYPE RK4
 #define C_REAL_DATATYPE c_float
 
@@ -565,6 +664,8 @@
 #define  gpublas_PRECISION_SYMV gpublas_CSYMV
 #define  gpublas_PRECISION_COPY gpublas_CCOPY
 #define  gpublas_PRECISION_TRSM gpublas_CTRSM
+#define  gpublas_PRECISION_DOT  gpublas_CDOT
+#define  gpublas_PRECISION_SCAL gpublas_CSCAL
 #define  gpusolver_PRECISION_TRTRI gpusolver_CTRTRI
 #define  gpusolver_PRECISION_POTRF gpusolver_CPOTRF
 #define  cublas_PRECISION_GEMM cublas_CGEMM
@@ -578,6 +679,18 @@
 #define  gpu_copy_PRECISION_tmp2_tmat2 gpu_copy_float_complex_tmp2_tmat2
 #define  gpu_copy_PRECISION_a_tmat1 gpu_copy_float_complex_a_tmat1
 #define  gpu_copy_PRECISION_a_tmatc gpu_copy_float_complex_a_tmatc
+#define  gpu_copy_PRECISION_a_aux_bc gpu_copy_float_complex_a_aux_bc
+#define  gpu_copy_PRECISION_aux_bc_aux_mat gpu_copy_float_complex_aux_bc_aux_mat
+#define  gpu_copy_PRECISION_tmp2_c gpu_copy_float_complex_tmp2_c
+#define  gpu_copy_and_set_zeros_PRECISION gpu_copy_and_set_zeros_float_complex
+#define  gpu_dot_product_PRECISION gpu_dot_product_float_complex
+#define  gpu_dot_product_and_assign_PRECISION gpu_dot_product_and_assign_float_complex
+#define  gpu_set_e_vec_scale_set_one_store_v_row_PRECISION gpu_set_e_vec_scale_set_one_store_v_row_float_complex
+#define  gpu_store_u_v_in_uv_vu_PRECISION gpu_store_u_v_in_uv_vu_float_complex
+#define  gpu_update_matrix_element_add_PRECISION gpu_update_matrix_element_add_float_complex
+#define  gpu_update_array_element_add_PRECISION gpu_update_array_element_add_float_complex
+#define  gpu_hh_transform_PRECISION gpu_hh_transform_float_complex
+#define  gpu_transpose_reduceadd_vectors_copy_block_PRECISION gpu_transpose_reduceadd_vectors_copy_block_float_complex
 #define  mkl_offload_PRECISION_GEMM mkl_offload_CGEMM
 #define  mkl_offload_PRECISION_GEMV mkl_offload_CGEMV
 #define  mkl_offload_PRECISION_TRMM mkl_offload_CTRMM
@@ -600,6 +713,10 @@
 #define ELPA_PRECISION_SSMV elpa_cssmv
 #define ELPA_PRECISION_SSR2 elpa_cssr2
 
+#define GPU_SCALE_QMAT_PRECISION gpu_scale_qmat_float_complex
+#define GPU_COPY_REAL_PART_TO_Q_PRECISION gpu_copy_real_part_to_q_float_complex
+
 #endif /* SINGLE PRECISION */
 
+
 #endif /* COMPLEXCASE */
